@@ -1,26 +1,15 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
 import doctest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import test_view, test_depends
+from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import doctest_setup, doctest_teardown
 
 
-class PurchaseInvoiceLineStandaloneTestCase(unittest.TestCase):
+class PurchaseInvoiceLineStandaloneTestCase(ModuleTestCase):
     'Test PurchaseInvoiceLineStandalone module'
-
-    def setUp(self):
-        trytond.tests.test_tryton.install_module(
-                'purchase_invoice_line_standalone')
-
-    def test0005views(self):
-        'Test views'
-        test_view('purchase_invoice_line_standalone')
-
-    def test0006depends(self):
-        'Test depends'
-        test_depends()
+    module = 'purchase_invoice_line_standalone'
 
 
 def suite():
